pub fn dispatch(cli: &Cli, action: &NetworkAction) -> i32Expand description
Route a parsed network action to its handler and render the result.
Returns the process exit code.
pub fn dispatch(cli: &Cli, action: &NetworkAction) -> i32Route a parsed network action to its handler and render the result.
Returns the process exit code.